@@ -5,21 +5,23 @@ from meutils.pipe import *
 from meutils.caches import rcache
 from meutils.decorators.retry import retrying
 
-username = "d1982743732"  # 包月
+username = "d1982743732"
 password = "1h29rymg"
 
 
 @rcache(ttl=2.5 * 60)
 @retrying()
-async def get_proxy_list():
+async def get_proxy_list(n: int = 1):
     secret_id = os.getenv("KDLAPI_SECRET_ID")
     signature = os.getenv("KDLAPI_SIGNATURE")
-    url = f"https://dps.kdlapi.com/api/getdps/?secret_id={secret_id}&signature={signature}&num=1&pt=1&format=json&sep=1"
+    url = f"https://dps.kdlapi.com/api/getdps/?secret_id={secret_id}&signature={signature}&num={n}&pt=1&format=json&sep=1"
     async with httpx.AsyncClient(timeout=30) as client:
         response = await client.get(url)
         response.raise_for_status()
         proxy_list = response.json().get('data').get('proxy_list')
 
+        logger.debug(f"获取到的代理: {proxy_list}")
+
         return [f"http://{username}:{password}@{proxy}" for proxy in proxy_list]
 
 
