@@ -214,18 +214,15 @@ async def get_next_token(
 
                 return token
             elif await check_token(token, threshold=min_points * 2):
-                logger.info("写回队列「大于最小消耗」")  # 大于最小消耗 至少两次 才写回
+                logger.info("写回队列「大于最小消耗*2」")  # 大于最小消耗 至少两次 才写回
 
                 await redis_aclient.rpush(feishu_url, token)
                 _ttl > 1 and await redis_aclient.expire(feishu_url, _ttl)
 
                 return token
-            # elif await check_token(token):
-            #     logger.info("不写回队列「最后一次消耗」")
-            #
-            #     return token
 
             logger.info(f"不写回队列: {token}")
+            return token
 
         else:  # 更新tokens到redis
             df = await aget_spreadsheet_values(feishu_url=feishu_url, to_dataframe=True)
