@@ -7,11 +7,12 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  :
-import os
 
 from meutils.pipe import *
-from meutils.decorators.retry import retrying
 from meutils.caches import rcache
+from meutils.decorators.retry import retrying
+from meutils.config_utils.lark_utils import get_next_token
+
 from httpx import TimeoutException
 
 from openai import OpenAI, AsyncOpenAI
@@ -170,14 +171,14 @@ async def check_token_for_gemini(api_key):
 
 
 @retrying()
-async def check_token_for_ppinfra(api_key, threshold: float = 1):
+async def check_token_for_ppinfra(api_key, threshold: float = 1):  # 1块钱 10000
     if not isinstance(api_key, str):
         return await check_tokens(api_key, partial(check_token_for_ppinfra, threshold=threshold))
     try:
         client = AsyncOpenAI(base_url="https://api.ppinfra.com/v3/user", api_key=api_key)
         data = await client.get("", cast_to=object)
         logger.debug(data)  # credit_balance
-        return data["credit_balance"] > threshold
+        return data["credit_balance"] >= threshold
     except TimeoutException as e:
         raise
 
@@ -220,13 +221,44 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
         base_url = os.getenv("VOLC_BASE_URL") or "https://ark.cn-beijing.volces.com/api/v3"
         client = AsyncOpenAI(base_url=base_url, api_key=api_key)
 
-        if purpose:
-            response = client.images.generate(
+        if purpose == "seedance":
+            url = "https://ark.cn-beijing.volces.com/api/v3/contents/generations/tasks"
+
+            payload = {
+                "model": "doubao-seedance-1-0-pro-250528",
+                # "model":"doubao-seedance-1-0-lite-i2v-250428",
+                "content": [
+                    {
+                        "type": "text",
+                        "text": "无人机以极快速度穿越复杂障碍或自然奇观，带来沉浸式飞行体验  --resolution 480p  --duration 5 --camerafixed false"
+                    },
+                    {
+                        "type": "image_url",
+                        "image_url": {
+                            "url": "https://ark-project.tos-cn-beijing.volces.com/doc_image/seepro_i2v.png"
+                        }
+                    }
+                ]
+            }
+            headers = {
+                'Authorization': f'Bearer {api_key}',
+                'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
+                'Content-Type': 'application/json'
+            }
+
+            response = requests.request("POST", url, headers=headers, json=payload)
+            logger.debug(response.json())
+            response.raise_for_status()
+        elif purpose:
+            response = await client.images.generate(
                 model="doubao-seedream-3-0-t2i-250415",
                 prompt="鱼眼镜头，一只猫咪的头部，画面呈现出猫咪的五官因为拍摄方式扭曲的效果。",
                 size="1024x1024",
                 response_format="url"
             )
+            logger.debug(response.json())
+            response.raise_for_status()
+
         else:
 
             response = await client.chat.completions.create(
@@ -234,6 +266,7 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
                 messages=[{"role": "user", "content": "hi"}],
                 max_tokens=1
             )
+
         return True
     except TimeoutException as e:
         raise
@@ -325,6 +358,13 @@ async def check_token_for_gitee(api_key, threshold: float = 1):
         return False
 
 
+async def get_valid_token_for_fal(feishu_url: Optional[str] = None):
+    feishu_url = feishu_url or "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=iFRwmM"
+    _ = await get_next_token(feishu_url, check_token_for_fal, ttl=600)
+    logger.debug(_)
+    return _
+
+
 if __name__ == '__main__':
     from meutils.config_utils.lark_utils import get_next_token_for_polling, get_series
 
@@ -360,7 +400,7 @@ if __name__ == '__main__':
 
     # arun(check_token_for_ppinfra("sk_F0kgPyCMTzmOH_-VCEJucOK8HIrbnLGYm_IWxBToHZQ"))
 
-    # arun(check_token_for_volc("f1f394db-59e9-4cdd-9d12-b11d50173efc"))
+    arun(check_token_for_volc("97237d3b-76b3-4a92-8150-5b64bba0b8b1"))
     # arun(check_token_for_volc("279749bd-ba5e-4962-9c65-eb6604b65594"))
 
     # arun(check_token_for_ppinfra("sk_mCb5sRGTi6GXkSRp5F679Rbs0V_Hfee3p85lccGXCOo"))
@@ -370,6 +410,8 @@ if __name__ == '__main__':
 
     # arun(check_token_for_fal("56d8a95e-2fe6-44a6-8f7d-f7f9c83eec24:537f06b6044770071f5d86fc7fcd6d6f"))
 
-    arun(check_token_for_ppinfra("sk_IeM4wjPIsgQFpfGqIOdMpHNF28qGLu1wxvh_vy3DiWM", threshold=1))
+    # arun(check_token_for_ppinfra("sk_ib2EjSVnXfB5hSlVuckpejRNXLIU3MaD1wxvXnsvdxQ", threshold=18000))
 
     # arun(check_token_for_gitee("NWVXUPI38OQVXZGOEL3D23I9YUQWZPV23GVVBW1X"))
+
+    # arun(get_valid_token_for_fal())
