@@ -17,6 +17,7 @@ from meutils.llm.openai_utils import to_openai_params
 from meutils.schemas.openai_types import CompletionRequest
 
 from meutils.apis.proxy.kdlapi import get_one_proxy
+from openai import APIStatusError
 
 
 class Completions(object):
@@ -37,7 +38,7 @@ class Completions(object):
         ###########################################################################
         # 开启视觉模型
         if not any(i in request.model.lower() for i in ["vl", 'vision', 'doubao-seed']) and (
-        urls := request.last_urls.get("image_url")):
+                urls := request.last_urls.get("image_url")):
             # logger.debug(request)
             if request.model.startswith(("gemini",)):
 
@@ -88,8 +89,25 @@ class Completions(object):
                 data['model'] = data['model'].removesuffix("-thinking")  # 开启思考
                 data['reasoning_effort'] = 'low'
 
-        logger.debug(data)
-        return await self.client.chat.completions.create(**data)
+        # logger.debug(data)
+        try:
+            response = await self.client.chat.completions.create(**data)
+            return response
+        except APIStatusError as e:
+            logger.debug(e)
+            # logger.debug(e.response.json())
+            # logger.debug(e.response.status_code)
+
+            if e.response.status_code > 403 and any(i in self.base_url for i in {"siliconflow", "modelscope"}):
+                proxy = await get_one_proxy()
+                client = AsyncOpenAI(
+                    base_url=self.base_url,
+                    api_key=self.api_key,
+                    http_client=httpx.AsyncClient(proxy=proxy, timeout=100)
+                )
+                response = await client.chat.completions.create(**data)
+                return response
+            raise e
 
 
 if __name__ == '__main__':
@@ -97,8 +115,9 @@ if __name__ == '__main__':
 
     request = CompletionRequest(
         # model="gemini-2.0-flash",
-        model="glm-4-flash",
-        # model="deepseek/deepseek-r1-turbo",
+        # model="glm-4-flash",
+        # model="deepseek-ai/DeepSeek-V3",
+        model="Qwen/Qwen3-8B1",
 
         messages=[
             {
@@ -114,15 +133,15 @@ if __name__ == '__main__':
             {"role": "user", "content": [
                 {
                     "type": "text",
-                    "text": "解释下"
+                    "text": "解释下" * 30000
                 },
-                {
-                    "image_url": {
-                        # "detail": "auto",
-                        "url": "https://osshk.share704.com/file/upload/2025/04/14/1911575959253815296.jpg"
-                    },
-                    "type": "image_url"
-                }
+                # {
+                #     "image_url": {
+                #         # "detail": "auto",
+                #         "url": "https://oss.ffire.cc/files/kling_watermark.png"
+                #     },
+                #     "type": "image_url"
+                # }
             ]}
         ],
         stream=False,
@@ -178,9 +197,9 @@ if __name__ == '__main__':
         "n": 1,
         "reasoning_effort": None
     }
-    api_key = os.getenv("GOOGLE_API_KEY")
-    base_url = os.getenv("GOOGLE_BASE_URL")
-    arun(Completions(api_key=api_key, base_url=base_url).create(request.construct(**d)))
+    # api_key = os.getenv("GOOGLE_API_KEY")
+    # base_url = os.getenv("GOOGLE_BASE_URL")
+    # arun(Completions(api_key=api_key, base_url=base_url).create(request.construct(**d)))
 
     # request = CompletionRequest(
     #     # model="gemini-2.0-flash",
@@ -195,6 +214,6 @@ if __name__ == '__main__':
     #     stream=False,
     #     max_tokens=None,
     # )
-    # api_key = "sk_LLktDFVC7GNqcGgVoxO1rA70_YHCM_2vaQz2dfwy9tY"
-    # base_url = "https://api.ppinfra.com/v3/openai"
-    # arun(Completions(api_key=api_key, base_url=base_url).create(request))
+    api_key = os.getenv("SILICONFLOW_API_KEY")
+    base_url = "https://api.siliconflow.cn"
+    arun(Completions(api_key=api_key, base_url=base_url).create(request))
