@@ -1091,6 +1091,9 @@ MODEL_RATIO = {
     "gpt-4.1-mini-2025-04-14": 0.2,
     "gpt-4.1-nano-2025-04-14": 0.05,
 
+    "gpt-oss-20b": 0.025,
+    "gpt-oss-120b": 0.05,
+
     "o1": 7.5,
     "o1-2024-12-17": 7.5,
 
@@ -1248,6 +1251,8 @@ COMPLETION_RATIO = {
     "gpt-4.1-nano-2025-04-14": 4,
 
     "gpt-image-1": 8,
+    "gpt-oss-20b": 4,
+    "gpt-oss-120b": 4,
 
     # claude
     "claude-3-5-haiku-20241022": 5,
